@@ -66,8 +66,13 @@ class WSGIApp:
 
         if match:
             args, route = match
-            status, headers, resp_data = route["func"](request, *args)
-
+            try:
+                status, headers, resp_data = route["func"](request, *args)
+            except (ValueError, TypeError) as err:
+                raise RuntimeError(
+                    "Proper HTTP response not returned by request handler for path "
+                    + f"'{request.path}'"
+                ) from err
         start_response(status, headers)
         return resp_data
 
